/* (C) 2022 YiRing, Inc. */
package com.yiring.common.exception;

import cn.hutool.core.convert.Convert;
import com.yiring.common.core.I18n;
import java.io.Serial;
import lombok.AccessLevel;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.FieldDefaults;
import org.jetbrains.annotations.PropertyKey;

/**
 * 业务状态异常
 *
 * @author Jim
 * @version 0.1
 * 2022/3/28 11:36
 */

@SuppressWarnings("unused")
@EqualsAndHashCode(callSuper = true)
@Data
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class BusinessException extends RuntimeException {

    @Serial
    private static final long serialVersionUID = -4226669531686389671L;

    /**
     * 业务状态
     */
    Integer code;

    /**
     * 业务状态异常消息
     */
    String message;

    public BusinessException(@PropertyKey(resourceBundle = I18n.RESOURCE_BUNDLE) String message) {
        String prefix = "Code.";
        if (message.startsWith(prefix)) {
            String code = message.replaceAll(".*(\\d+).*", "$1");
            this.code = Convert.toInt(code);
            this.message = message;
        } else {
            this.code = -1;
            this.message = "Unknown Error";
        }
    }

    public BusinessException(int code, @PropertyKey(resourceBundle = I18n.RESOURCE_BUNDLE) String message) {
        this.code = code;
        this.message = message;
    }

    public static BusinessException i18n(@PropertyKey(resourceBundle = I18n.RESOURCE_BUNDLE) String message) {
        return new BusinessException(message);
    }
}
